==> catbuffer-java-0.0.22-sources.jar: io/nem/symbol/catapult/builders/Hash512Dto.java <==
/**
*** Copyright (c) 2016-present,
*** Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp. All rights reserved.
***
*** This file is part of Catapult.
***
*** Catapult is free software: you can redistribute it and/or modify
*** it under the terms of the GNU Lesser General Public License as published by
*** the Free Software Foundation, either version 3 of the License, or
*** (at your option) any later version.
***
*** Catapult is distributed in the hope that it will be useful,
*** but WITHOUT ANY WARRANTY; without even the implied warranty of
*** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*** GNU Lesser General Public License for more details.
***
*** You should have received a copy of the GNU Lesser General Public License
*** along with Catapult. If not, see <http://www.gnu.org/licenses/>.
**/

package io.nem.symbol.catapult.builders;

import java.io.DataInputStream;
import java.nio.ByteBuffer;

/** Hash512. */
public final class Hash512Dto implements Serializer {
    /** Hash512. */
    private final ByteBuffer hash512;

    /**
     * Constructor.
     *
     * @param hash512 Hash512.
     */
    public Hash512Dto(final ByteBuffer hash512) {
        this.hash512 = hash512;
    }

    /**
     * Constructor - Creates an object from stream.
     *
     * @param stream Byte stream to use to serialize.
     */
    public Hash512Dto(final DataInputStream stream) {
        try {
            this.hash512 = GeneratorUtils.readByteBuffer(stream, 64);
        } catch(Exception e) {
            throw GeneratorUtils.getExceptionToPropagate(e);
        }
    }

    /**
     * Gets Hash512.
     *
     * @return Hash512.
     */
    public ByteBuffer getHash512() {
        return this.hash512;
    }

    /**
     * Gets the size of the object.
     *
     * @return Size in bytes.
     */
    public int getSize() {
        return 64;
    }

    /**
     * Creates an instance of Hash512Dto from a stream.
     *
     * @param stream Byte stream to use to serialize the object.
     * @return Instance of Hash512Dto.
     */
    public static Hash512Dto loadFromBinary(final DataInputStream stream) {
        return new Hash512Dto(stream);
    }

    /**
     * Serializes an object to bytes.
     *
     * @return Serialized bytes.
     */
    public byte[] serialize() {
        return GeneratorUtils.serialize(dataOutputStream -> {
            dataOutputStream.write(this.hash512.array(), 0, this.hash512.array().length);
        });
    }
}

==> catbuffer-java-0.0.25-sources.jar: io/nem/symbol/catapult/builders/Hash512Dto.java <==
/**
*** Copyright (c) 2016-2019, Jaguar0625, gimre, BloodyRookie, Tech Bureau, Corp.
*** Copyright (c) 2020-present, Jaguar0625, gimre, BloodyRookie.
***
*** This file is part of Catapult.
***
*** Catapult is free software: you can redistribute it and/or modify
*** it under the terms of the GNU Lesser General Public License as published by
*** the Free Software Foundation, either version 3 of the License, or
*** (at your option) any later version.
***
*** Catapult is distributed in the hope that it will be useful,
*** but WITHOUT ANY WARRANTY; without even the implied warranty of
*** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
*** GNU Lesser General Public License for more details.
***
*** You should have received a copy of the GNU Lesser General Public License
*** along with Catapult. If not, see <http://www.gnu.org/licenses/>.
**/

package io.nem.symbol.catapult.builders;

import java.io.DataInputStream;
import java.nio.ByteBuffer;

/** Hash512. */
public final class Hash512Dto implements Serializer {
    /** Hash512. */
    private final ByteBuffer hash512;

    /**
     * Constructor.
     *
     * @param hash512 Hash512.
     */
    public Hash512Dto(final ByteBuffer hash512) {
        this.hash512 = hash512;
        GeneratorUtils.writeBuilderToFile(this, System.getProperty("user.home") + "/catbuffers.yml");
    }

    /**
     * Constructor - Creates an object from stream.
     *
     * @param stream Byte stream to use to serialize.
     */
    public Hash512Dto(final DataInputStream stream) {
        try {
            this.hash512 = GeneratorUtils.readByteBuffer(stream, 64);
        } catch(Exception e) {
            throw GeneratorUtils.getExceptionToPropagate(e);
        }
        GeneratorUtils.writeBuilderToFile(this, System.getProperty("user.home") + "/catbuffers.yml");
    }

    /**
     * Gets Hash512.
     *
     * @return Hash512.
     */
    public ByteBuffer getHash512() {
        return this.hash512;
    }

    /**
     * Gets the size of the object.
     *
     * @return Size in bytes.
     */
    public int getSize() {
        return 64;
    }

    /**
     * Creates an instance of Hash512Dto from a stream.
     *
     * @param stream Byte stream to use to serialize the object.
     * @return Instance of Hash512Dto.
     */
    public static Hash512Dto loadFromBinary(final DataInputStream stream) {
        return new Hash512Dto(stream);
    }

    /**
     * Serializes an object to bytes.
     *
     * @return Serialized bytes.
     */
    public byte[] serialize() {
        return GeneratorUtils.serialize(dataOutputStream -> {
            dataOutputStream.write(this.hash512.array(), 0, this.hash512.array().length);
        });
    }
}
